@@ -1,37 +1,19 @@
-# $Id$
 # Created: Tue 27 Aug 2013 06:09:42 PM IDT
-# Last Changed: Wed 11 Sep 2013 11:44:57 AM IDT
-
-=head1 NAME
-
-Text::Bidi::Array::Byte - Dual-life byte arrays
-
-=head1 SYNOPSIS
-
-    use Text::Bidi::Array::Byte;
-    my $a = new Text::Bidi::Array::Byte "abc";
-    say $a->[1]; # says 98
-    say $$a; # says abc
-    say "$a"; # also says abc
-
-=head1 DESCRIPTION
-
-This is an derived class of L<Text::Bidi::Array> designed to hold C<byte> 
-arrays. See L<Text::Bidi::Array> for details on usage of this class. Each 
-element of the array representation corresponds to an octet in the string 
-representation, at the same location.
-
-=cut
-
-package Text::Bidi::Array::Byte;
+# Last Changed: Fri 20 Sep 2013 08:57:53 AM IDT
 
 use 5.10.0;
 use warnings;
 use integer;
 use strict;
-use Carp;
 
-our $VERSION = 1.1;
+package Text::Bidi::Array::Byte;
+{
+  $Text::Bidi::Array::Byte::VERSION = '2.06';
+}
+# ABSTRACT: Dual-life byte arrays
+
+
+use Carp;
 
 use Text::Bidi::Array;
 use base qw(Text::Bidi::Array);
@@ -66,14 +48,42 @@ sub STORESIZE {
 
 1;
 
+__END__
+
+=pod
+
+=head1 NAME
+
+Text::Bidi::Array::Byte - Dual-life byte arrays
+
+=head1 VERSION
+
+version 2.06
+
+=head1 SYNOPSIS
+
+    use Text::Bidi::Array::Byte;
+    my $a = new Text::Bidi::Array::Byte "abc";
+    say $a->[1]; # says 98
+    say $$a; # says abc
+    say "$a"; # also says abc
+
+=head1 DESCRIPTION
+
+This is an derived class of L<Text::Bidi::Array> designed to hold C<byte> 
+arrays. See L<Text::Bidi::Array> for details on usage of this class. Each 
+element of the array representation corresponds to an octet in the string 
+representation, at the same location.
+
 =head1 AUTHOR
 
-Moshe Kamensky  (E<lt>kamensky@cpan.orgE<gt>) - Copyright (c) 2013
+Moshe Kamensky <kamensky@cpan.org>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software. You may copy or 
-redistribute it under the same terms as Perl itself.
+This software is copyright (c) 2013 by Moshe Kamensky.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
